==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/hu_HU.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nem írható a \"config\" könyvtár!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Ez rendszerint úgy oldható meg, hogy írási jogot adunk a webszervernek a config könyvtárra.",
    "See %s" : "Lásd %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Ez rendszerint úgy oldható meg, hogy %sírási jogot adunk a webszervernek a config könyvtárra%s.",
    "Sample configuration detected" : "A példabeállítások vannak beállítva",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Úgy tűnik a példakonfigurációt próbálja ténylegesen használni. Ez nem támogatott, és működésképtelenné teheti a telepítést. Kérjük olvassa el a dokumentációt és azt követően változtasson a config.php-n!",
    "PHP %s or higher is required." : "PHP %s vagy ennél újabb szükséges.",
    "PHP with a version lower than %s is required." : "Ennél régebbi PHP szükséges: %s.",
    "Following databases are supported: %s" : "A következő adatbázis nem támogatott: %s",
    "The library %s is not available." : "A könyvtár %s nem áll rendelkezésre.",
    "ownCloud %s or higher is required." : "ownCoud %s vagy ennél újabb szükséges.",
    "ownCloud %s or lower is required." : "ownCoud %s vagy ennél régebbi szükséges.",
    "Help" : "Súgó",
    "Personal" : "Személyes",
    "Users" : "Felhasználók",
    "Admin" : "Adminsztráció",
    "Recommended" : "Ajánlott",
    "No app name specified" : "Nincs az alkalmazás név megadva.",
    "Unknown filetype" : "Ismeretlen file tipús",
    "Invalid image" : "Hibás kép",
    "today" : "ma",
    "yesterday" : "tegnap",
    "_%n day ago_::_%n days ago_" : ["%n napja","%n napja"],
    "last month" : "múlt hónapban",
    "_%n month ago_::_%n months ago_" : ["%n hónappal ezelőtt","%n hónappal ezelőtt"],
    "last year" : "tavaly",
    "_%n year ago_::_%n years ago_" : ["%n éve","%n éve"],
    "_%n hour ago_::_%n hours ago_" : ["%n órával ezelőtt","%n órával ezelőtt"],
    "seconds ago" : "pár másodperce",
    "web services under your control" : "webszolgáltatások saját kézben",
    "Empty filename is not allowed" : "Üres fájlnév nem engedétlyezett",
    "Dot files are not allowed" : "Pontozott fájlok nem engedétlyezettek",
    "4-byte characters are not supported in file names" : "4-byte karakterek nem támogatottak a fájl nevekben.",
    "File name is a reserved word" : "A fajl neve egy rezervált szó",
    "File name is too long" : "A fájlnév túl hosszú!",
    "Can't read file" : "Nem olvasható a fájl",
    "App directory already exists" : "Az alkalmazás mappája már létezik",
    "Can't create app folder. Please fix permissions. %s" : "Nem lehetett létrehozni az alkalmazás mappáját. Kérem ellenőrizze a jogosultságokat. %s",
    "No source specified when installing app" : "Az alkalmazás telepítéséhez nincs forrás megadva",
    "No href specified when installing app from http" : "Az alkalmazás http-n keresztül történő telepítéséhez nincs href hivetkozás megadva",
    "No path specified when installing app from local file" : "Az alkalmazás helyi telepítéséhez nincs útvonal (mappa) megadva",
    "Archives of type %s are not supported" : "A(z) %s típusú tömörített állomány nem támogatott",
    "Failed to open archive when installing app" : "Nem sikerült megnyitni a tömörített állományt a telepítés során",
    "App does not provide an info.xml file" : "Az alkalmazás nem szolgáltatott info.xml file-t",
    "App can't be installed because of not allowed code in the App" : "Az alkalmazást nem lehet telepíteni, mert abban nem engedélyezett programkód szerepel",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Az alkalmazás nem telepíthető, mert nem kompatibilis az ownCloud jelen verziójával.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Az alkalmazást nem lehet telepíteni, mert tartalmazza a \n<shipped>\ntrue\n</shipped>\ncímkét, ami a nem szállított alkalmazások esetén nem engedélyezett",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Az alkalmazást nem lehet telepíteni, mert az info.xml/version-ben megadott verzió nem egyezik az alkalmazás-kiszolgálón feltüntetett verzióval.",
    "Application is not enabled" : "Az alkalmazás nincs engedélyezve",
    "Authentication error" : "Azonosítási hiba",
    "Token expired. Please reload page." : "A token lejárt. Frissítse az oldalt.",
    "Unknown user" : "Ismeretlen felhasználó",
    "%s enter the database username." : "%s adja meg az adatbázist elérő felhasználó login nevét.",
    "%s enter the database name." : "%s adja meg az adatbázis nevét.",
    "%s you may not use dots in the database name" : "%s az adatbázis neve nem tartalmazhat pontot",
    "Oracle connection could not be established" : "Az Oracle kapcsolat nem hozható létre",
    "Oracle username and/or password not valid" : "Az Oracle felhasználói név és/vagy jelszó érvénytelen",
    "DB Error: \"%s\"" : "Adatbázis hiba: \"%s\"",
    "Offending command was: \"%s\"" : "A hibát ez a parancs okozta: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Vagy egy létező felhasználó vagy az adminisztrátor bejelentkezési nevét kell megadnia",
    "Offending command was: \"%s\", name: %s, password: %s" : "A hibát okozó parancs ez volt: \"%s\", login név: %s, jelszó: %s",
    "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név és/vagy jelszó érvénytelen",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "A Mac OS X nem támogatott és %s nem lesz teljesen működőképes. Csak saját felelősségre használja!",
    "For the best results, please consider using a GNU/Linux server instead." : "A legjobb eredmény érdekében érdemes GNU/Linux-alapú kiszolgálót használni.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Kérlek távolítsd el az open_basedir beállítást a php.ini-ből, vagy válts 64bit-es PHP-ra.",
    "Set an admin username." : "Állítson be egy felhasználói nevet az adminisztrációhoz.",
    "Set an admin password." : "Állítson be egy jelszót az adminisztrációhoz.",
    "Can't create or write into the data directory %s" : "Nem sikerült  létrehozni vagy irni  a \"data\" könyvtárba %s",
    "%s shared »%s« with you" : "%s megosztotta Önnel ezt:  »%s«",
    "%s via %s" : "%s über %s",
    "Sharing %s failed, because the file does not exist" : "%s megosztása sikertelen, mert a fájl nem létezik",
    "You are not allowed to share %s" : "Önnek nincs jogosultsága %s megosztására",
    "Sharing %s failed, because the user %s is the item owner" : "%s megosztása nem sikerült, mert %s felhasználó az állomány tulajdonosa",
    "Sharing %s failed, because the user %s does not exist" : "%s megosztása nem sikerült, mert %s felhasználó nem létezik",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s megosztása nem sikerült, mert %s felhasználó nem tagja egyik olyan csoportnak sem, aminek %s tagja",
    "Sharing %s failed, because this item is already shared with %s" : "%s megosztása nem sikerült, mert ez már meg van osztva %s-vel",
    "Sharing %s failed, because the group %s does not exist" : "%s megosztása nem sikerült, mert %s csoport nem létezik",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s megosztása nem sikerült, mert %s felhasználó nem tagja a %s csoportnak",
    "You need to provide a password to create a public link, only protected links are allowed" : "Meg kell adnia egy jelszót is, mert a nyilvános linkek csak jelszóval védetten használhatók",
    "Sharing %s failed, because sharing with links is not allowed" : "%s megosztása nem sikerült, mert a linkekkel történő megosztás nincs engedélyezve",
    "Share type %s is not valid for %s" : "A %s megosztási típus nem érvényes %s-re",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nem sikerült %s-re beállítani az elérési jogosultságokat, mert a megadottak túllépik a %s-re érvényes jogosultságokat",
    "Setting permissions for %s failed, because the item was not found" : "Nem sikerült %s-re beállítani az elérési jogosultságokat, mert a kérdéses állomány nem található",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nem lehet beállítani a lejárati időt. A megosztások legfeljebb ennyi idővel járhatnak le a létrehozásukat követően: %s",
    "Cannot set expiration date. Expiration date is in the past" : "Nem lehet beállítani a lejárati időt, mivel a megadott lejárati időpont már elmúlt.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Az %s megosztási alrendszernek támogatnia kell az OCP\\Share_Backend interface-t",
    "Sharing backend %s not found" : "A %s megosztási alrendszer nem található",
    "Sharing backend for %s not found" : "%s megosztási alrendszere nem található",
    "Sharing %s failed, because the user %s is the original sharer" : "%s megosztása nem sikerült, mert %s felhasználó az eredeti megosztó",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s megosztása nem sikerült, mert a jogosultságok túllépik azt, ami %s rendelkezésére áll",
    "Sharing %s failed, because resharing is not allowed" : "%s megosztása nem sikerült, mert a megosztás továbbadása nincs engedélyezve",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s megosztása nem sikerült, mert %s megosztási alrendszere nem találja",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s megosztása nem sikerült, mert a fájl nem található a gyorsítótárban",
    "Could not find category \"%s\"" : "Ez a kategória nem található: \"%s\"",
    "Apps" : "Alkalmazások",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "A felhasználónévben csak a következő karakterek fordulhatnak elő: \"a-z\", \"A-Z\", \"0-9\", és \"_.@-\"",
    "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
    "A valid password must be provided" : "Érvényes jelszót kell megadnia",
    "The username is already being used" : "Ez a bejelentkezési név már foglalt",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nincs telepítve adatbázis-meghajtóprogram (sqlite, mysql vagy postgresql).",
    "Microsoft Windows Platform is not supported" : "Microsoft Windows platform nem támogatott",
    "Cannot write into \"config\" directory" : "Nem írható a \"config\" könyvtár",
    "Cannot write into \"apps\" directory" : "Nem írható az \"apps\" könyvtár",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ez rendszerint úgy oldható meg, hogy %sírási jogot adunk a webszervernek az app könyvtárra%s, vagy letiltjuk a config fájlban az appstore használatát.",
    "Cannot create \"data\" directory (%s)" : "Nem sikerült létrehozni a \"data\" könyvtárt (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Ez rendszerint úgy oldható meg, hogy <a href=\"%s\" target=\"_blank\">írásjogot adunk a webszervernek a gyökérkönyvtárra</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Az elérési problémák rendszerint megoldhatók azzal, ha a %swebszervernek írásjogot adunk a gyökérkönyvtárra%s.",
    "Setting locale to %s failed" : "A lokalizáció %s-re való állítása nem sikerült",
    "Please install one of these locales on your system and restart your webserver." : "Kérjük állítsa be a következő lokalizációk valamelyikét a rendszeren és indítsa újra a webszervert!",
    "Please ask your server administrator to install the module." : "Kérje meg a rendszergazdát, hogy telepítse a modult!",
    "PHP module %s not installed." : "A %s PHP modul nincs telepítve.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ezt valószínűleg egy gyorsítótár ill. kódgyorsító, mint pl, a Zend, OPcache vagy eAccelererator okozza.",
    "PHP modules have been installed, but they are still listed as missing?" : "A PHP modulok telepítve vannak, de a listában mégsincsenek felsorolva?",
    "Please ask your server administrator to restart the web server." : "Kérje meg a rendszergazdát, hogy indítsa újra a webszervert!",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 szükséges",
    "Please upgrade your database version" : "Kérem frissítse az adatbázis-szoftvert!",
    "Error occurred while checking PostgreSQL version" : "Hiba történt a PostgreSQL verziójának ellenőrzése közben",
    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Kérjük gondoskodjon róla, hogy a PostgreSQL legalább 9-es verziójú legyen, vagy ellenőrizze a naplófájlokat, hogy mi okozta a hibát!",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Kérjük módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználó ne listázhassa!",
    "Data directory (%s) is readable by other users" : "Az adatkönyvtár (%s) más felhasználók számára is olvasható ",
    "Data directory (%s) is invalid" : "Érvénytelen a megadott adatkönyvtár (%s) ",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Kérjük ellenőrizze, hogy az adatkönyvtár tartalmaz a gyökerében egy \".ocdata\" nevű állományt!",
    "Could not obtain lock type %d on \"%s\"." : "Nem sikerült %d típusú zárolást elérni itt: \"%s\"."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/hu_HU.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nem írható a \"config\" könyvtár!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Ez rendszerint úgy oldható meg, hogy írási jogot adunk a webszervernek a config könyvtárra.",
    "See %s" : "Lásd %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Ez rendszerint úgy oldható meg, hogy %sírási jogot adunk a webszervernek a config könyvtárra%s.",
    "Sample configuration detected" : "A példabeállítások vannak beállítva",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Úgy tűnik a példakonfigurációt próbálja ténylegesen használni. Ez nem támogatott, és működésképtelenné teheti a telepítést. Kérjük olvassa el a dokumentációt és azt követően változtasson a config.php-n!",
    "PHP %s or higher is required." : "PHP %s vagy ennél újabb szükséges.",
    "PHP with a version lower than %s is required." : "Ennél régebbi PHP szükséges: %s.",
    "Following databases are supported: %s" : "A következő adatbázis nem támogatott: %s",
    "The library %s is not available." : "A könyvtár %s nem áll rendelkezésre.",
    "Following platforms are supported: %s" : "Ezek a platformok támogatottak: %s",
    "ownCloud %s or higher is required." : "ownCoud %s vagy ennél újabb szükséges.",
    "ownCloud %s or lower is required." : "ownCoud %s vagy ennél régebbi szükséges.",
    "Help" : "Súgó",
    "Personal" : "Személyes",
    "Users" : "Felhasználók",
    "Admin" : "Adminsztráció",
    "Recommended" : "Ajánlott",
    "No app name specified" : "Nincs az alkalmazás név megadva.",
    "Unknown filetype" : "Ismeretlen file tipús",
    "Invalid image" : "Hibás kép",
    "today" : "ma",
    "yesterday" : "tegnap",
    "_%n day ago_::_%n days ago_" : ["%n napja","%n napja"],
    "last month" : "múlt hónapban",
    "_%n month ago_::_%n months ago_" : ["%n hónapja","%n hónapja"],
    "last year" : "tavaly",
    "_%n year ago_::_%n years ago_" : ["%n éve","%n éve"],
    "_%n hour ago_::_%n hours ago_" : ["%n órája","%n órája"],
    "_%n minute ago_::_%n minutes ago_" : ["%n perce","%n perce"],
    "seconds ago" : "pár másodperce",
    "web services under your control" : "webszolgáltatások saját kézben",
    "Empty filename is not allowed" : "Üres fájlnév nem engedétlyezett",
    "Dot files are not allowed" : "Pontozott fájlok nem engedétlyezettek",
    "4-byte characters are not supported in file names" : "4-byte karakterek nem támogatottak a fájl nevekben.",
    "File name is a reserved word" : "A fajl neve egy rezervált szó",
    "File name contains at least one invalid character" : "A fájlnév legalább egy érvénytelen karaktert tartalmaz!",
    "File name is too long" : "A fájlnév túl hosszú!",
    "File is currently busy, please try again later" : "A fájl jelenleg elfoglalt, kérjük próbáld újra később!",
    "Can't read file" : "Nem olvasható a fájl",
    "App directory already exists" : "Az alkalmazás mappája már létezik",
    "Can't create app folder. Please fix permissions. %s" : "Nem lehetett létrehozni az alkalmazás mappáját. Kérem ellenőrizze a jogosultságokat. %s",
    "No source specified when installing app" : "Az alkalmazás telepítéséhez nincs forrás megadva",
    "No href specified when installing app from http" : "Az alkalmazás http-n keresztül történő telepítéséhez nincs href hivetkozás megadva",
    "No path specified when installing app from local file" : "Az alkalmazás helyi telepítéséhez nincs útvonal (mappa) megadva",
    "Archives of type %s are not supported" : "A(z) %s típusú tömörített állomány nem támogatott",
    "Failed to open archive when installing app" : "Nem sikerült megnyitni a tömörített állományt a telepítés során",
    "App does not provide an info.xml file" : "Az alkalmazás nem szolgáltatott info.xml file-t",
    "App can't be installed because of not allowed code in the App" : "Az alkalmazást nem lehet telepíteni, mert abban nem engedélyezett programkód szerepel",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Az alkalmazás nem telepíthető, mert nem kompatibilis az ownCloud jelen verziójával.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Az alkalmazást nem lehet telepíteni, mert tartalmazza a \n<shipped>\ntrue\n</shipped>\ncímkét, ami a nem szállított alkalmazások esetén nem engedélyezett",
    "Application is not enabled" : "Az alkalmazás nincs engedélyezve",
    "Authentication error" : "Azonosítási hiba",
    "Token expired. Please reload page." : "A token lejárt. Frissítse az oldalt.",
    "Unknown user" : "Ismeretlen felhasználó",
    "%s enter the database username." : "%s adja meg az adatbázist elérő felhasználó login nevét.",
    "%s enter the database name." : "%s adja meg az adatbázis nevét.",
    "%s you may not use dots in the database name" : "%s az adatbázis neve nem tartalmazhat pontot",
    "Oracle connection could not be established" : "Az Oracle kapcsolat nem hozható létre",
    "Oracle username and/or password not valid" : "Az Oracle felhasználói név és/vagy jelszó érvénytelen",
    "DB Error: \"%s\"" : "Adatbázis hiba: \"%s\"",
    "Offending command was: \"%s\"" : "A hibát ez a parancs okozta: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Vagy egy létező felhasználó vagy az adminisztrátor bejelentkezési nevét kell megadnia",
    "Offending command was: \"%s\", name: %s, password: %s" : "A hibát okozó parancs ez volt: \"%s\", login név: %s, jelszó: %s",
    "PostgreSQL username and/or password not valid" : "A PostgreSQL felhasználói név és/vagy jelszó érvénytelen",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "A Mac OS X nem támogatott és %s nem lesz teljesen működőképes. Csak saját felelősségre használja!",
    "For the best results, please consider using a GNU/Linux server instead." : "A legjobb eredmény érdekében érdemes GNU/Linux-alapú kiszolgálót használni.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Kérlek távolítsd el az open_basedir beállítást a php.ini-ből, vagy válts 64bit-es PHP-ra.",
    "Set an admin username." : "Állítson be egy felhasználói nevet az adminisztrációhoz.",
    "Set an admin password." : "Állítson be egy jelszót az adminisztrációhoz.",
    "Can't create or write into the data directory %s" : "Nem sikerült  létrehozni vagy irni  a \"data\" könyvtárba %s",
    "Invalid Federated Cloud ID" : "Érvénytelen Egyesített Felhő Azonosító",
    "%s shared »%s« with you" : "%s megosztotta Önnel ezt:  »%s«",
    "%s via %s" : "%s über %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s megosztása sikertelen, mert a megosztási alrendszer nem engedi a %l típus megosztását",
    "Sharing %s failed, because the file does not exist" : "%s megosztása sikertelen, mert a fájl nem létezik",
    "You are not allowed to share %s" : "Önnek nincs jogosultsága %s megosztására",
    "Sharing %s failed, because you can not share with yourself" : "%s megosztása sikertelen, mert magaddal nem oszthatod meg",
    "Sharing %s failed, because the user %s does not exist" : "%s megosztása nem sikerült, mert %s felhasználó nem létezik",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s megosztása nem sikerült, mert %s felhasználó nem tagja egyik olyan csoportnak sem, aminek %s tagja",
    "Sharing %s failed, because this item is already shared with %s" : "%s megosztása nem sikerült, mert ez már meg van osztva %s-vel",
    "Sharing %s failed, because this item is already shared with user %s" : "%s megosztása sikertelen, mert már meg van osztva %s felhasználóval",
    "Sharing %s failed, because the group %s does not exist" : "%s megosztása nem sikerült, mert %s csoport nem létezik",
    "Sharing %s failed, because %s is not a member of the group %s" : "%s megosztása nem sikerült, mert %s felhasználó nem tagja a %s csoportnak",
    "You need to provide a password to create a public link, only protected links are allowed" : "Meg kell adnia egy jelszót is, mert a nyilvános linkek csak jelszóval védetten használhatók",
    "Sharing %s failed, because sharing with links is not allowed" : "%s megosztása nem sikerült, mert a linkekkel történő megosztás nincs engedélyezve",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s megosztása sikertelen, mert %s nem található, talán a szerver jelenleg nem elérhető.",
    "Share type %s is not valid for %s" : "A %s megosztási típus nem érvényes %s-re",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nem sikerült %s-re beállítani az elérési jogosultságokat, mert a megadottak túllépik a %s-re érvényes jogosultságokat",
    "Setting permissions for %s failed, because the item was not found" : "Nem sikerült %s-re beállítani az elérési jogosultságokat, mert a kérdéses állomány nem található",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nem lehet beállítani a lejárati időt. A megosztások legfeljebb ennyi idővel járhatnak le a létrehozásukat követően: %s",
    "Cannot set expiration date. Expiration date is in the past" : "Nem lehet beállítani a lejárati időt, mivel a megadott lejárati időpont már elmúlt.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Nem lehet beállítani a lejárati időt. A megosztásoknak kötelező megadni lejárati időt!",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Az %s megosztási alrendszernek támogatnia kell az OCP\\Share_Backend interface-t",
    "Sharing backend %s not found" : "A %s megosztási alrendszer nem található",
    "Sharing backend for %s not found" : "%s megosztási alrendszere nem található",
    "Sharing failed, because the user %s is the original sharer" : "Megosztás sikertelen, mert %s felhasználó az eredeti megosztó",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "%s megosztása nem sikerült, mert a jogosultságok túllépik azt, ami %s rendelkezésére áll",
    "Sharing %s failed, because resharing is not allowed" : "%s megosztása nem sikerült, mert a megosztás továbbadása nincs engedélyezve",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s megosztása nem sikerült, mert %s megosztási alrendszere nem találja",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s megosztása nem sikerült, mert a fájl nem található a gyorsítótárban",
    "Could not find category \"%s\"" : "Ez a kategória nem található: \"%s\"",
    "Apps" : "Alkalmazások",
    "A valid username must be provided" : "Érvényes felhasználónevet kell megadnia",
    "A valid password must be provided" : "Érvényes jelszót kell megadnia",
    "The username is already being used" : "Ez a bejelentkezési név már foglalt",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nincs telepítve adatbázis-meghajtóprogram (sqlite, mysql vagy postgresql).",
    "Microsoft Windows Platform is not supported" : "Microsoft Windows platform nem támogatott",
    "Cannot write into \"config\" directory" : "Nem írható a \"config\" könyvtár",
    "Cannot write into \"apps\" directory" : "Nem írható az \"apps\" könyvtár",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ez rendszerint úgy oldható meg, hogy %sírási jogot adunk a webszervernek az app könyvtárra%s, vagy letiltjuk a config fájlban az appstore használatát.",
    "Cannot create \"data\" directory (%s)" : "Nem sikerült létrehozni a \"data\" könyvtárt (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Ez rendszerint úgy oldható meg, hogy <a href=\"%s\" target=\"_blank\">írásjogot adunk a webszervernek a gyökérkönyvtárra</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Az elérési problémák rendszerint megoldhatók azzal, ha a %swebszervernek írásjogot adunk a gyökérkönyvtárra%s.",
    "Setting locale to %s failed" : "A lokalizáció %s-re való állítása nem sikerült",
    "Please install one of these locales on your system and restart your webserver." : "Kérjük állítsa be a következő lokalizációk valamelyikét a rendszeren és indítsa újra a webszervert!",
    "Please ask your server administrator to install the module." : "Kérje meg a rendszergazdát, hogy telepítse a modult!",
    "PHP module %s not installed." : "A %s PHP modul nincs telepítve.",
    "PHP setting \"%s\" is not set to \"%s\"." : "%s PHP beállítás nincs \"%s\"-re állítva.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ezt valószínűleg egy gyorsítótár ill. kódgyorsító, mint pl, a Zend, OPcache vagy eAccelererator okozza.",
    "PHP modules have been installed, but they are still listed as missing?" : "A PHP modulok telepítve vannak, de a listában mégsincsenek felsorolva?",
    "Please ask your server administrator to restart the web server." : "Kérje meg a rendszergazdát, hogy indítsa újra a webszervert!",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 szükséges",
    "Please upgrade your database version" : "Kérem frissítse az adatbázis-szoftvert!",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Kérjük módosítsa a könyvtár elérhetőségi engedélybeállítását 0770-re, hogy a tartalmát más felhasználó ne listázhassa!",
    "Data directory (%s) is readable by other users" : "Az adatkönyvtár (%s) más felhasználók számára is olvasható ",
    "Data directory (%s) must be an absolute path" : "Az adatkönyvtárnak (%s) abszolút elérési útnak kell lennie",
    "Data directory (%s) is invalid" : "Érvénytelen a megadott adatkönyvtár (%s) ",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Kérjük ellenőrizze, hogy az adatkönyvtár tartalmaz a gyökerében egy \".ocdata\" nevű állományt!",
    "Could not obtain lock type %d on \"%s\"." : "Nem sikerült %d típusú zárolást elérni itt: \"%s\".",
    "Storage not available" : "A tároló elérhetetlen."
},
"nplurals=2; plural=(n != 1);");
